@@ -18,8 +18,8 @@ from tablib.compat import OrderedDict, unicode
 
 
 __title__ = 'tablib'
-__version__ = '0.11.3'
-__build__ = 0x001103
+__version__ = '0.11.4'
+__build__ = 0x001104
 __author__ = 'Kenneth Reitz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2016 Kenneth Reitz'
@@ -143,6 +143,7 @@ class Dataset(object):
 
     :param \*args: (optional) list of rows to populate Dataset
     :param headers: (optional) list strings for Dataset header row
+    :param title: (optional) string to use as title of the Dataset
 
 
     .. admonition:: Format Attributes Definition
@@ -223,7 +224,8 @@ class Dataset(object):
         result = []
 
         # Add unicode representation of headers.
-        result.append([unicode(h) for h in self.__headers])
+        if self.__headers:
+            result.append([unicode(h) for h in self.__headers])
 
         # Add unicode representation of rows.
         result.extend(list(map(unicode, row)) for row in self._data)
@@ -232,7 +234,8 @@ class Dataset(object):
         field_lens = list(map(max, zip(*lens)))
 
         # delimiter between header and data
-        result.insert(1, ['-' * length for length in field_lens])
+        if self.__headers:
+            result.insert(1, ['-' * length for length in field_lens])
 
         format_string = '|'.join('{%s:%s}' % item for item in enumerate(field_lens))
 
